# Changelog for `magodo`

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog], and this project adheres to
[Semantic Versioning].

[Keep a Changelog]: https://keepachangelog.com/en/1.0.0/
[Semantic Versioning]: https://semver.org/


## [Unreleased](https://github.com/bbugyi200/magodo/compare/0.4.0...HEAD)

No notable changes have been made.


## [0.4.1](https://github.com/bbugyi200/magodo/compare/0.4.0...0.4.1) - 2022-01-12

### Added

* Migrated all code from old "bbugyi200/todotxt" GitHub repo to the new "bbugyi200/magodo" repo.


## [0.4.0](https://github.com/bbugyi200/magodo/releases/tag/0.4.0) - 2022-01-12

### Changed

* *BREAKING CHANGE*: Changed name of pacakge from "todotxt" to "magodo".

### Miscellaneous

* *WARNING*: Not a real release. Only claims the "magodo" PyPI package name.


## [0.3.1](https://github.com/bbugyi200/todotxt/compare/0.3.0...0.3.1) - 2022-01-11

### Fixed

* Fix recursion bug with `TodoGroup.from_path()`.


## [0.3.0](https://github.com/bbugyi200/todotxt/compare/0.2.0...0.3.0) - 2022-01-11

### Added

* Add new `TodoGroup` class.

### Fixed

* Fixed multiple bugs with `Todo` class.

### Removed

* Remove old `read_todos_from_file()` function.


## [0.2.0](https://github.com/bbugyi200/todotxt/compare/0.1.0...0.2.0) - 2022-01-10

### Added

* Add `todotxt.Todo` class.
* Add `todotxt.read_todos_from_file()` function.

### Miscellaneous

* Brought test coverage up to 99%!
* First _real_ release.


## [0.1.0](https://github.com/bbugyi200/todotxt/releases/tag/0.1.0) - 2022-01-10

### Miscellaneous

* First release.
